package
module
Version:
v1.0.0
Opens a new window with list of versions in this module.
Published: Jul 21, 2025
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
Documentation
¶
const (
AlreadyExistsErr ErrorCode = iota + 100000
NotFoundErr
CouldNotGenerateErr
ProviderErr
WeakPasswordErr
BadRequestErr
UnknownErr
)
type IAMError struct {
Message string `json:"message"`
Code ErrorCode `json:"error_code"`
}
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.